ensemble subpackage
===================

Submodules
----------

gaussian\_ensemble module
-------------------------

.. automodule:: skrmt.ensemble.gaussian_ensemble
   :members:
   :undoc-members:
   :show-inheritance:

wishart\_ensemble module
------------------------

.. automodule:: skrmt.ensemble.wishart_ensemble
   :members:
   :undoc-members:
   :show-inheritance:

manova\_ensemble module
-----------------------

.. automodule:: skrmt.ensemble.manova_ensemble
   :members:
   :undoc-members:
   :show-inheritance:

circular\_ensemble module
-------------------------

.. automodule:: skrmt.ensemble.circular_ensemble
   :members:
   :undoc-members:
   :show-inheritance:

plot\_law module
----------------

.. automodule:: skrmt.ensemble.plot_law
   :members:
   :undoc-members:
   :show-inheritance:

tridiagonal\_utils routines
---------------------------

.. automodule:: skrmt.ensemble.tridiagonal_utils
   :members:
   :undoc-members:
   :show-inheritance:
